@@ -61,11 +61,11 @@ def find_first(
 
 
 def squash(items: Iterable[Cmd[_T]]) -> Cmd[Iterable[_T]]:
-    def _action(act: CmdUnwrapper) -> Iterable[_T]:
+    def _action(unwrapper: CmdUnwrapper) -> Iterable[_T]:
         for item in items:
-            yield act.unwrap(item)
+            yield unwrapper.act(item)
 
-    return new_cmd(_action)
+    return Cmd.new_cmd(_action)
 
 
 def until_none(items: Iterable[Optional[_T]]) -> Iterable[_T]:
